@@ -4,7 +4,7 @@
 import datetime
 import requests
 import logging
-from .consts import CONFIG, LOGS, ORANGE_MONEY, REDIS_DB, IzyTV
+from .consts import CONFIG, LOGS, ORANGE_MONEY, REDIS_DB, IzyTV, TODAY_STR
 
 
 class OrangeMoney(object):
@@ -13,7 +13,6 @@ class OrangeMoney(object):
         self.url_api = ORANGE_MONEY["url_api"]
 
     def requestToken(self):
-        LOGS.logger.info("\n\nOrangeMoney - requesting token...\n\n")
         try:
             response = requests.post(
                 ORANGE_MONEY["url_token"],
@@ -24,20 +23,15 @@ class OrangeMoney(object):
                 },
                 data={'grant_type': 'client_credentials'}
             )
-            LOGS.logger.info(response)
             if response.status_code == 200:
-                LOGS.logger.info("\n\nOrangemoney - token request successful\n\n")
                 return response.json()['access_token']
             return None
         except Exception as e:
-            LOGS.logger.info('\n\nAn exception occured. Token request failed.\n')
-            LOGS.logger.info(e)
+            LOGS.logger.error("[OrangeMoney] token request: {}".format(e))
             return None
 
     def paymentRequest(self, data):
         token = self.requestToken()
-        LOGS.logger.info("\n\ntoken: {}\n\n".format(token))
-        LOGS.logger.info("\n\n====== OrangeMoney paymentRequest =======\n\n")
         if token:
             or_data = {
                 "order_id": data["operation_id"],
@@ -51,7 +45,6 @@ class OrangeMoney(object):
                 "currency": ORANGE_MONEY['currency'],
             }
             try:
-                LOGS.logger.info("\n\nSending orangemoney payment request...\n\n")
                 response = requests.post(
                     "{}/webpayment".format(ORANGE_MONEY["url_api"]),
                     headers={
@@ -60,45 +53,34 @@ class OrangeMoney(object):
                     },
                     json=or_data
                 )
-                LOGS.logger.info("\n\nStatus code: {}\n\n".format(response.status_code))
-                LOGS.logger.info(response.json())
+                LOGS.logger.info(
+                    "[OrangeMoney][{}]{}".format(
+                        data["operation_id"],
+                        response.json()
+                    )
+                )
 
             except Exception as e:
                 response = {
                     "code": "046-06-404",
                     "response": {},
-                    "message": "Serveur Orange Money introuvable.",
+                    "message": str(e),
                     "status": 404
                 }
-                LOGS.logger.error(str(e))
+                LOGS.logger.error(
+                    "[OrangeMoney][{}]{}".format(
+                        data["operation_id"],
+                        str(e)
+                    )
+                )
 
             if response.status_code == 201:
-                LOGS.logger.info("\n\nOrangemoney payment request: SUCCESS.\n\n")
-                LOGS.logger.info("\n\nStatus code: {}\n\n".format(response.status_code))
+                # Orange always returns 201 regardless of the actual transaction status
                 jresponse = response.json()
                 if jresponse.get("status"):
                     if jresponse["status"] == 201 and jresponse["message"] == "OK":
-                        today = datetime.datetime.today()
-                        transaction_date = today.strftime("%Y-%m-%d %H:%M:%S")
-                        re_data = {
-                            "TransactionDate": transaction_date,
-                            "amount": data["amount"],
-                            "order_id": data["operation_id"],
-                            "label": data["label"],
-                            "device_id": data["device_id"],
-                            "other": data["other"],
-                            "client_refnum": data["client_refnum"],
-                            "offre_refnum": data["offre_refnum"],
-                            "partner_ref": jresponse["pay_token"],
-                            "operator": "orange-izytv",
-                            "caller_num": "320000000",
-                            "service_type": "izytv",
-                            "status": "En attente de paiement",
-                            "info": "Activation en attente",
-                        }
-                        LOGS.logger.info(re_data)
-                        redis_key = "request:payment:{}".format(jresponse["pay_token"])
-                        REDIS_DB.hmset(redis_key, re_data)
+                        # save transaction informations into Redis
+                        self.writeToRedis(data, jresponse)
                         response = {
                             "code": "046-06-200",
                             "response": {
@@ -134,23 +116,57 @@ class OrangeMoney(object):
                         "message": jresponse["message"],
                         "status": jresponse["code"]
                     }
-            else:
-                LOGS.logger.info("\n\nOrangemoney payment request: FAIL.\n\n")
-                LOGS.logger.info("\n\nStatus code: {}\n\n".format(response.status_code))
+            else:  # Orange couldn't process the transaction request
                 response = {
                     "code": "046-06-{}".format(response.status_code),
                     "response": {},
                     "message": "Serveur Orange Money introuvable",
                     "status": response.status_code
                 }
-                LOGS.logger.info("\n\nRequest unsuccesful\n\n")
+                LOGS.logger.error(
+                    "[OrangMoney][{}]{}".format(
+                        data["operation_id"],
+                        response,
+                    )
+                )
         return response
 
+    def writeToRedis(self, data, jresponse):
+        """Writes the initial transaction inside Redis for asynchronous status checks. """
+        today = TODAY_STR
+        re_data = {
+            "TransactionDate": today,
+            "amount": data["amount"],
+            "order_id": data["operation_id"],
+            "label": data["label"],
+            "device_id": data["device_id"],
+            "other": data["other"],
+            "client_refnum": data["client_refnum"],
+            "offre_refnum": data["offre_refnum"],
+            "partner_ref": jresponse["pay_token"],
+            "operator": "orange-izytv",
+            "caller_num": "320000000",
+            "service_type": "izytv",
+            "status": "En attente de paiement",
+            "info": "Activation en attente",
+        }
+        LOGS.logger.info(
+            "[OrangeMoney][{}][write in Redis] {}\n".format(
+                data["operation_id"],
+                re_data,
+            )
+        )
+        redis_key = "request:payment:{}".format(jresponse["pay_token"])
+        REDIS_DB.hmset(redis_key, re_data)
+
+# transaction status request related functions
+
     def checkTransactionStatus(self, data):
+        """
+        Main function for checking the status of a transaction at Orange.
+        """
         order_id = data["order_id"]
         auth_token = self.requestToken()
-        LOGS.logger.info("\n\n====== OrangeMoney TransactionStatusRequest =======\n\n")
-        LOGS.logger.info("\n\nauth_token: {}\n\n".format(auth_token))
         if auth_token:
             data = {
                 "order_id": data["order_id"],
@@ -166,19 +182,36 @@ class OrangeMoney(object):
                     },
                     json=data
                 )
-                LOGS.logger.info(response.json())
+                LOGS.logger.info(
+                    "[OrangeMoney][{}]{}\n".format(
+                        order_id,
+                        response.json(),
+                    )
+                )
             except Exception as e:
-                LOGS.logger.warning("\n\nAn exception occured \n\n")
-                LOGS.logger.error(e)
+                LOGS.logger.error(
+                    "[OrangeMoney][{}]{}\n".format(
+                        order_id,
+                        str(e),
+                    )
+                )
                 response = {
                     "code": "046-06-404",
                     "response": {},
-                    "message": "Serveur Orange Money introuvable",
+                    "message": str(e),
                     "status": 404
                 }
                 return response
+
             if response.status_code == 201:
+                # Orange returns 201 regardless of the actual transaction status
                 jresponse = response.json()
+                # update Redis
+                self.updateRefPartner({
+                    "redis_key": "request:payment:{}".format(data["pay_token"]),
+                    "tnxid": jresponse["txnid"],
+                })
+                # build response to return
                 status = jresponse['status']
                 choices = {
                     'SUCCESS': [200, 4],
@@ -197,17 +230,12 @@ class OrangeMoney(object):
                     "message": jresponse['status'],
                     "status": choices[status][-1],
                 }
-                LOGS.logger.info("\n\nFinal result\n\n")
                 LOGS.logger.info(
                     "[OrangeMoney][] {}\n".format(
                         order_id,
                         response,
                     )
                 )
-                self.updateRefPartner({
-                    "redis_key": "request:payment:{}".format(data["pay_token"]),
-                    "tnxid": jresponse["txnid"],
-                })
             return response
 
     def updateRefPartner(self, transaction):
@@ -248,7 +276,10 @@ class OrangeMoney(object):
 # status requests functions
 
     def checkTransactionStatusRedis(self, order_id):
-        """Used by 4D in order to check a given transaction current status"""
+        """
+        Used by 4D in order to check a given transaction current status.
+        Value inside Redis is returned.
+        """
 
         redis_key = "request:payment:{}".format(order_id)
         val = REDIS_DB.hgetall(redis_key.encode('utf-8'))
